using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Text;
using System.Text;
using System.Windows.Forms;
using BarCode;
using System.Drawing.Printing;

namespace BarcodeHarness
{
    public partial class BarcodeTestHarness : Form
    {
        private int convertType;
        PrintDocument pd = new PrintDocument();

        public BarcodeTestHarness()
        {
            InitializeComponent();
        }

        private void btnConvert128_Click(object sender, EventArgs e)
        {
            textEncoded.Text = BarcodeConverter128.StringToBarcode(textToConvert.Text);
            convertType = CalculateConvertType(textToConvert.Text, 1);
        }

        private void btnConvert39_Click(object sender, EventArgs e)
        {
            // Convert with checksum
            textEncoded.Text = BarcodeConverter39.StringToBarcode(textToConvert.Text, true);
            convertType = CalculateConvertType(textEncoded.Text, 2);
        }

        private int CalculateConvertType(string outputString, int GoodReturnValue)
        {
            if (outputString != string.Empty)
            {
                if (GoodReturnValue == 1)
                    lblBarcode.Font = new Font("Code 128", 28);
                else
                    lblBarcode.Font = new Font("Code 3 de 9", 28);
                lblBarcode.Text = textEncoded.Text;
                btnPrint.Enabled = true;
                btnPreview.Enabled = true;
                return GoodReturnValue;
            }
            lblBarcode.Text = "";
            btnPrint.Enabled = false;
            btnPreview.Enabled = false;
            return 0;
        }

        private void BarcodeTestHarness_Load(object sender, EventArgs e)
        {
            convertType = CalculateConvertType("", 0);
            pd.PrintPage += new PrintPageEventHandler(pd_PrintPage);
        }


        private void btnPrint_Click(object sender, EventArgs e)
        {
            pd.Print();
        }

        private void btnPreview_Click(object sender, EventArgs e)
        {
            printPreviewDialog1.Document = pd;
            ((Form)printPreviewDialog1).WindowState = FormWindowState.Maximized;
            printPreviewDialog1.ShowDialog();
        }


        void pd_PrintPage(object sender, PrintPageEventArgs ev)
        {
            PointF pf = new PointF(ev.MarginBounds.Left, ev.MarginBounds.Top);
            pf = PrintString(ev, pf, "Printing", "Arial", 14, false);
            if (convertType == 1)
                pf = PrintString(ev, pf, "Code128", "Arial", 14, true);
            else
                pf = PrintString(ev, pf, "Code 39", "Arial", 14, true);
            pf.Y += 15;
            pf = PrintString(ev, pf, "Original Text : " + textToConvert.Text, "Arial", 10, true);
            pf = PrintString(ev, pf, "Encoded Text : " + textEncoded.Text, "Arial", 10, true);
            pf.Y += 10;
            if (convertType == 1)
                pf = PrintString(ev, pf, textEncoded.Text, "Code 128", 28, true);
            else
                pf = PrintString(ev, pf, textEncoded.Text, "Code 3 de 9", 28, true);
        }


        private PointF PrintString(PrintPageEventArgs ev, PointF pf, string value, String font, float size, bool newline)
        {
            Font printFont = new Font(font, size);
            ev.Graphics.DrawString(value, printFont, Brushes.Black, pf);

            if (!newline)
            {
                pf.X += ev.Graphics.MeasureString(value, printFont).Width;
            }
            else
            {
                pf.X = ev.MarginBounds.Left;
                pf.Y += (printFont.GetHeight(ev.Graphics));
            }
            return pf;
        }
    }
}